==> ejc-quality-impl-3.0.0-20240515.021721-46-sources.jar: com/ejianc/business/quatity/controller/TargetManagementController.java <==
package com.ejianc.business.quatity.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.ejianc.business.quatity.entity.CompanyGoalsEntity;
import com.ejianc.business.quatity.model.vo.CompanyTargetAddVo;
import com.ejianc.business.quatity.service.TargetManagementServer;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.QueryParam;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.util.List;


/**
 * @Author: LCL
 * @Date: 2024/5/13 下午1:45
 * @Description: 目标管理
 */
@Controller
@RequestMapping("targetManagement")
@RequiredArgsConstructor
public class TargetManagementController {
    private final TargetManagementServer server;

    /**
     * 公司目标-新增
     *
     * @param vo CompanyTargetAddVo
     * @return 结果
     * @see CompanyTargetAddVo
     */
    @RequestMapping(value = "company/add", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<CompanyGoalsEntity> companyAdd(@RequestBody @Valid CompanyTargetAddVo vo) {
        return CommonResponse.success("公司目标-新增成功", server.companyAdd(vo));
    }

    /**
     * 公司目标-查询
     *
     * @param param param
     * @return IPage<CompanyGoalsEntity>
     */
    @RequestMapping(value = "company/list", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<CompanyGoalsEntity>> companyList(@RequestBody QueryParam param) {
        return CommonResponse.success("公司目标-查询", server.companyList(param));
    }

    /**
     * 公司目标-详情
     *
     * @param id id
     * @return CompanyGoalsEntity
     */
    @RequestMapping(value = "company/detail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<CompanyGoalsEntity> companyDetail(@RequestParam(value = "id") Long id) {
        return CommonResponse.success("公司目标-查询", server.companyDetail(id));
    }

    /**
     * 公司目标-删除
     *
     * @param ids ids
     */
    @RequestMapping(value = "company/del", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> companyDel(@RequestBody @Valid List<Long> ids) {
        server.companyDel(ids);
        return CommonResponse.success("公司目标-删除成功");
    }

    /**
     * 公司目标-导出
     *
     * @param ids      ids
     * @param response response
     */
    @RequestMapping(value = "company/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> companyExcelExport(@RequestBody List<Long> ids, HttpServletResponse response) {
        server.companyExcelExport(ids, response);
        return CommonResponse.success("公司目标-导出成功");
    }

    /**
     * 公司目标导入
     *
     * @return 结果
     */
    @RequestMapping(value = "company/excelImport", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<Boolean> companyExcelImport(HttpServletRequest request, HttpServletResponse response) {
        server.companyExcelImport(request, response);
        return CommonResponse.success("公司目标-导入成功");
    }

}

==> ejc-quality-impl-3.0.0-20240522.061523-47-sources.jar: com/ejianc/business/quatity/controller/TargetManagementController.java <==
package com.ejianc.business.quatity.controller;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.ejianc.business.quatity.entity.CompanyGoalsEntity;
import com.ejianc.business.quatity.model.vo.CompanyTargetAddVo;
import com.ejianc.business.quatity.model.vo.CompanyTargetEditVo;
import com.ejianc.business.quatity.service.TargetManagementServer;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.QueryParam;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.util.List;


/**
 * @Author: LCL
 * @Date: 2024/5/13 下午1:45
 * @Description: 目标管理
 */
@Controller
@RequestMapping("targetManagement")
@RequiredArgsConstructor
public class TargetManagementController {
    private final TargetManagementServer server;

    /**
     * 公司目标-新增
     *
     * @param vo CompanyTargetAddVo
     * @return CompanyGoalsEntity
     * @see CompanyTargetAddVo
     */
    @RequestMapping(value = "company/add", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<CompanyGoalsEntity> companyAdd(@RequestBody @Valid CompanyTargetAddVo vo) {
        return CommonResponse.success("公司目标-新增成功", server.companyAdd(vo));
    }

    /**
     * 公司目标-编辑
     *
     * @param vo CompanyTargetEditVo
     * @return 结果
     * @see CompanyTargetEditVo
     */
    @RequestMapping(value = "company/edit", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<CompanyGoalsEntity> companyEdit(@RequestBody @Valid CompanyTargetEditVo vo) {
        return CommonResponse.success("公司目标-编辑成功", server.companyEdit(vo));
    }

    /**
     * 公司目标-查询
     *
     * @param param param
     * @return IPage<CompanyGoalsEntity>
     */
    @RequestMapping(value = "company/list", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<CompanyGoalsEntity>> companyList(@RequestBody QueryParam param) {
        return CommonResponse.success("公司目标-查询", server.companyList(param));
    }

    /**
     * 公司目标-详情
     *
     * @param id id
     * @return CompanyGoalsEntity
     */
    @RequestMapping(value = "company/detail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<CompanyGoalsEntity> companyDetail(@RequestParam(value = "id") Long id) {
        return CommonResponse.success("公司目标-查询", server.companyDetail(id));
    }

    /**
     * 公司目标-删除
     *
     * @param ids ids
     */
    @RequestMapping(value = "company/del", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> companyDel(@RequestBody @Valid List<Long> ids) {
        server.companyDel(ids);
        return CommonResponse.success("公司目标-删除成功");
    }

    /**
     * 公司目标-导出
     *
     * @param ids      ids
     * @param response response
     */
    @RequestMapping(value = "company/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> companyExcelExport(@RequestBody List<Long> ids, HttpServletResponse response) {
        server.companyExcelExport(ids, response);
        return CommonResponse.success("公司目标-导出成功");
    }

    /**
     * 公司目标导入
     *
     * @return 结果
     */
    @RequestMapping(value = "company/excelImport", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<JSONObject> companyExcelImport(HttpServletRequest request) {
        return server.companyExcelImport(request);
    }

    /**
     * 公司目标导入保存
     *
     * @return 结果
     */
    @RequestMapping(value = "company/excelImport/save", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<Boolean> companyExcelImportSave(@RequestBody List<CompanyGoalsEntity> importVos) {
        if (ListUtil.isEmpty(importVos)) {
            return CommonResponse.error("导入的数据为空！");
        }
        server.companyExcelImportSave(importVos);
        return CommonResponse.success("公司目标-导入成功");
    }

}
